MerkleTree

Struct MerkleTree 

pub struct MerkleTree<D: Digest> { /* private fields */ }
Flat, Fixed-Size, Read only Merkle Tree

Expects the length of leaves to be equal or near(less) to a power of two.

Implementations

Source

impl<D: Digest + FixedOutputReset> MerkleTree<D>
where Output<D>: Pod + Copy,

pub fn new(data: &[Output<D>]) -> Self

Constructs a new Merkle tree from the given hash leaves.

pub fn new_unhashed(data: &[Output<D>]) -> UnhashedMerkleTree<D>

Constructs a new Merkle tree from the given hash leaves, without hashing internal nodes.

pub fn root(&self) -> &Output<D>

Returns the root hash of the Merkle tree

pub fn leaves(&self) -> &[Output<D>]

Returns the leaves of the Merkle tree

pub fn contains(&self, leaf: &Output<D>) -> bool

Checks if the given leaf is contained in the Merkle tree

pub fn get_proof_iter(&self, leaf: &Output<D>) -> Option<SiblingIter<'_, D>>

Get proof for a given leaf

pub fn as_raw_bytes(&self) -> &[u8]

Returns the raw bytes of the Merkle tree nodes

pub fn from_raw_bytes(bytes: &[u8]) -> Self

From raw bytes, reconstruct the Merkle tree

Panics
  • If the length of bytes is not a multiple of the hash output size.
  • If the number of nodes implied by bytes is not consistent with a valid Merkle tree structure.