pub struct MerkleTree<D: Digest> { /* private fields */ }Expand description
Flat, Fixed-Size, Read only Merkle Tree
Expects the length of leaves to be equal or near(less) to a power of two.
Implementations
Sourceimpl<D: Digest + FixedOutputReset> MerkleTree<D>
impl<D: Digest + FixedOutputReset> MerkleTree<D>
Sourcepub fn new(data: &[Output<D>]) -> Self
pub fn new(data: &[Output<D>]) -> Self
Constructs a new Merkle tree from the given hash leaves.
Sourcepub fn new_unhashed(data: &[Output<D>]) -> UnhashedMerkleTree<D>
pub fn new_unhashed(data: &[Output<D>]) -> UnhashedMerkleTree<D>
Constructs a new Merkle tree from the given hash leaves, without hashing internal nodes.
Sourcepub fn contains(&self, leaf: &Output<D>) -> bool
pub fn contains(&self, leaf: &Output<D>) -> bool
Checks if the given leaf is contained in the Merkle tree
Sourcepub fn get_proof_iter(&self, leaf: &Output<D>) -> Option<SiblingIter<'_, D>>
pub fn get_proof_iter(&self, leaf: &Output<D>) -> Option<SiblingIter<'_, D>>
Get proof for a given leaf
Sourcepub fn as_raw_bytes(&self) -> &[u8] ⓘ
pub fn as_raw_bytes(&self) -> &[u8] ⓘ
Returns the raw bytes of the Merkle tree nodes
Sourcepub fn from_raw_bytes(bytes: &[u8]) -> Self
pub fn from_raw_bytes(bytes: &[u8]) -> Self
From raw bytes, reconstruct the Merkle tree
Panics
- If the length of
bytesis not a multiple of the hash output size. - If the number of nodes implied by
bytesis not consistent with a valid Merkle tree structure.